==> parodia_admin-1.0.2.tar.gz: lib/core/repository/mailTemplate.repository.dart <==
// GET
// /api/v1/dashboard/mail_templates/{id}

// PUT
// /api/v1/dashboard/mail_templates/{id}

// DELETE
// /api/v1/dashboard/mail_templates/{id}

// GET
// /api/v1/dashboard/mail_templates

// POST
// /api/v1/dashboard/mail_templates

// POST
// /api/v1/dashboard/mail_templates/{id}/recover

import 'package:parodia_admin/core/dto/mail_template.dto.dart';
import 'package:parodia_admin/core/dto/response_item.dto.dart';
import 'package:parodia_admin/core/dto/response_list.dto.dart';
import 'package:parodia_admin/core/enums.dart';
import 'package:parodia_admin/core/http/parodia_http.dart';
import 'package:parodia_admin/core/model/body_data.model.dart';
import 'package:parodia_admin/core/model/query.model.dart';
class MailTemplateRepository {
  ParodiaHTTP? _http;

  MailTemplateRepository(ParodiaHTTP http) {
    _http = http;
  }

   Future<ResponseItemDTO<MailTemplateDTO>> getById({String? id}) async {
    final response = await _http!.request(
      requestType: RequestType.get,
      path: '/mail_templates',
      param: id,
    );

    return ResponseItemDTO<MailTemplateDTO>(
      response: response,
      fromJson: MailTemplateDTO.fromJson,
    );
  }

  Future<ResponseListDTO<MailTemplateDTO>> getAll({StoreQuery? query}) async {
    final response = await _http!.request(
      requestType: RequestType.get,
      path: '/mail_templates',
      query: query,
    );

    return ResponseListDTO<MailTemplateDTO>(
      response: response,
      fromJson: MailTemplateDTO.fromJson,
    );
  }

  Future<ResponseItemDTO> create({MailTemplateBody? mailTemplate}) async {
    final response = await _http!.request(
      requestType: RequestType.post,
      path: '/mail_templates',
      data: mailTemplate,
    );

    return ResponseItemDTO(
      response: response,
      fromJson: null,
    );
  }

  Future<ResponseItemDTO> update({String? id, MailTemplateBody? mailTemplate}) async {
    final response = await _http!.request(
      requestType: RequestType.put,
      path: '/mail_templates',
      param: id,
      data: mailTemplate,
    );

    return ResponseItemDTO(
      response: response,
      fromJson: null,
    );
  }

  Future<ResponseItemDTO> delete({String? id}) async {
    final response = await _http!.request(
      requestType: RequestType.delete,
      path: '/mail_templates',
      param: id,
    );

    return ResponseItemDTO(
      response: response,
      fromJson: null,
    );
  }

  Future<ResponseItemDTO> recover({String? id}) async {
    final response = await _http!.request(
      requestType: RequestType.post,
      path: '/mail_templates/$id/recover',
    );

    return ResponseItemDTO(
      response: response,
      fromJson: null,
    );
  }
}

==> parodia_admin-1.0.20.tar.gz: lib/core/repository/mailTemplate.repository.dart <==
// GET
// /api/v1/dashboard/dashboard/mail_templates/{id}

// PUT
// /api/v1/dashboard/dashboard/mail_templates/{id}

// DELETE
// /api/v1/dashboard/dashboard/mail_templates/{id}

// GET
// /api/v1/dashboard/dashboard/mail_templates

// POST
// /api/v1/dashboard/dashboard/mail_templates

// POST
// /api/v1/dashboard/dashboard/mail_templates/{id}/recover

import 'package:parodia_admin/core/dto/mail_template.dto.dart';
import 'package:parodia_admin/core/dto/response_item.dto.dart';
import 'package:parodia_admin/core/dto/response_list.dto.dart';
import 'package:parodia_admin/core/enums.dart';
import 'package:parodia_admin/core/http/parodia_http.dart';
import 'package:parodia_admin/core/model/body_data.model.dart';
import 'package:parodia_admin/core/model/query.model.dart';
class MailTemplateRepository {
  ParodiaHTTP? _http;

  MailTemplateRepository(ParodiaHTTP http) {
    _http = http;
  }

   Future<ResponseItemDTO<MailTemplateDTO>> getById({String? id}) async {
    final response = await _http!.request(
      requestType: RequestType.get,
      path: '/dashboard/mail_templates',
      param: id,
    );

    return ResponseItemDTO<MailTemplateDTO>(
      response: response,
      fromJson: MailTemplateDTO.fromJson,
    );
  }

  Future<ResponseListDTO<MailTemplateDTO>> getAll({StoreQuery? query}) async {
    final response = await _http!.request(
      requestType: RequestType.get,
      path: '/dashboard/mail_templates',
      query: query,
    );

    return ResponseListDTO<MailTemplateDTO>(
      response: response,
      fromJson: MailTemplateDTO.fromJson,
    );
  }

  Future<ResponseItemDTO> create({MailTemplateBody? mailTemplate}) async {
    final response = await _http!.request(
      requestType: RequestType.post,
      path: '/dashboard/mail_templates',
      data: mailTemplate,
    );

    return ResponseItemDTO(
      response: response,
      fromJson: null,
    );
  }

  Future<ResponseItemDTO> update({String? id, MailTemplateBody? mailTemplate}) async {
    final response = await _http!.request(
      requestType: RequestType.put,
      path: '/dashboard/mail_templates',
      param: id,
      data: mailTemplate,
    );

    return ResponseItemDTO(
      response: response,
      fromJson: null,
    );
  }

  Future<ResponseItemDTO> delete({String? id}) async {
    final response = await _http!.request(
      requestType: RequestType.delete,
      path: '/dashboard/mail_templates',
      param: id,
    );

    return ResponseItemDTO(
      response: response,
      fromJson: null,
    );
  }

  Future<ResponseItemDTO> recover({String? id}) async {
    final response = await _http!.request(
      requestType: RequestType.post,
      path: '/dashboard/mail_templates/$id/recover',
    );

    return ResponseItemDTO(
      response: response,
      fromJson: null,
    );
  }
}
